/*
 * Copyright (c) 2017 Y. Burmeister
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */ 

#include <stdbool.h>
#include <stdint.h>
#include <stdlib.h>
#include <sys/cpuctl.h>
#include <sys/errno.h>
#include <sys/ioctl.h>

#include "main.h"
#include "msr.h"


// --------


/*
 * Checks if the given MSR exists.
 *
 * - msr: MSR to check.
 */
bool checkmsr(int32_t msr) {
	cpuctl_msr_args_t args;

	args.msr = msr;

	if (ioctl(options.fd, CPUCTL_RDMSR, &args) == -1)
	{
		return false;
	}

	return true;
}


/*
 * Reads the given MSR and returns it's data.
 *
 *  - msr: MSR to read.
 */
uint64_t getmsr(int32_t msr) {
	cpuctl_msr_args_t args;

	args.msr = msr;

	if (ioctl(options.fd, CPUCTL_RDMSR, &args) == -1)
	{
		exit_error(1, "ERROR: ioctl CPUCTL_RDMSR failed: %i\n", errno);
	}

	return args.data;
}

// --------

